@@ -1,4 +1,4 @@
-import dateutil
+import dateutil.parser
 from datetime import date, datetime, timezone as tz
 # import pandas as pd
 import uuid
@@ -9,6 +9,12 @@ import numpy as np
 def float_as_currency(val: float) -> str:
     return "${:,.2f}".format(round(val, 2))
 
+def float_parse(value) -> float:
+    try:
+        return float(value)
+    except Exception as e:
+        raise ValueError(f"Unable to parse value: {value} as a float") from e
+
 
 def int_tryParse(value) -> int:
     try:
@@ -25,7 +31,15 @@ def date_tryParse(value, allow_none: bool = True) -> date:
     return ret
 
 
-def datestamp_tryParse(value, include_time: bool = True, include_ms: bool = True, allow_none: bool = True) -> datetime:
+def datestamp_tryParse(value,
+                       remove_month: bool = False,
+                       remove_day: bool = False,
+                       remove_hrs: bool = False,
+                       remove_min: bool = False,
+                       remove_sec: bool = False,
+                       remove_ms: bool = False,
+                       include_time: bool = True,
+                       allow_none: bool = True) -> datetime:
     val = force_to_datetime_or_None(value)
 
     if val is None and not allow_none:
@@ -35,9 +49,27 @@ def datestamp_tryParse(value, include_time: bool = True, include_ms: bool = True
         return val
 
     if not include_time:
-        val = datetime.combine(val, datetime.min.time())
+        remove_min = True
+        remove_hrs = True
+        remove_sec = True
+        remove_ms = True
 
-    if not include_ms:
+    if remove_month:
+        val.replace(month=0)
+
+    if remove_day:
+        val.replace(day=0)
+
+    if remove_hrs:
+        val.replace(hour=0)
+
+    if remove_min:
+        val.replace(minute=0)
+
+    if remove_sec:
+        val.replace(second=0)
+
+    if remove_ms:
         val = val.replace(microsecond=0)
 
     return val
@@ -75,7 +107,15 @@ def force_to_datetime_or_None(val, force_to_midnight: bool = False):
             ts = (val - np.datetime64('1970-01-01T00:00:00Z')) / np.timedelta64(1, 's')
             ret = datetime.utcfromtimestamp(ts)
         else:
-            val = dateutil.parser.parse(val)
+            try:
+                val = dateutil.parser.parse(val)
+            except dateutil.parser.ParserError as e:
+                # attempt a parse of YYYYDDMM format
+                val = dateutil.parser.parse(val,
+                                            parserinfo=dateutil.parser.parserinfo(
+                                                                           yearfirst=True,
+                                                                           dayfirst=True
+                                                                       ))
             ret = force_to_datetime_or_None(val)
 
         # force to midnight if requested
@@ -88,6 +128,23 @@ def force_to_datetime_or_None(val, force_to_midnight: bool = False):
         logging.warning(f"unable to parse val {val} [{type(val)}] as datetime: {e}")
         return None
 
+def bool_tryparse(val: str | int | bool):
+    if type(val) == bool:
+        return val
+
+    if type(val) == str and val.upper() in ['F', 'FALSE']:
+        return False
+
+    if type(val) == int and val == 0:
+        return False
+
+    if type(val) == str and val.upper() in ['T', 'TRUE']:
+        return True
+
+    if type(val) == int and val == 1:
+        return True
+
+    raise ValueError(f"The val: {val} is unrecognized as bool")
 
 if __name__ == "__main__":
     try_vals = [
